{% extends "admin/change_list.html" %}
{% load i18n %}

{% block object-tools-items %}
    <li>
        <a href="{% url subscriber:export_csv %}">
            {% trans "Export CSV" %}
        </a>
    </li>
    {{ block.super }}
{% endblock %}
