{% extends "base.html" %}
{% load widget_tweaks i18n %}


{% block content %}
<form method="post">
    <div class="form-group{% if form.email.errors %} has-error{% endif %}">
        {% if form.email.errors %}
            <span class="help-block">{% for error in form.email.errors %}{{ error }}{% endfor %}</span>
        {% endif %}
        <label for="{{ form.email.auto_id }}" class="control-label">{{ form.email.label }}</label>
        {% render_field form.email class="form-control" required="" %}
    </div>
    <button type="submit" class="btn btn-default">{% trans "Unsubscribe" %}</button>
    {% csrf_token %}
</form>
{% endblock %}
